@@ -152,9 +152,9 @@ def TimerLoop(): #(interval: sampling*sample_smoothing*value_smoothing)
     if(r==1): #new data got added to array
 #        print "Got SensorData"
         
-        ProcessData()      
+        ProcessData(False)      
      
-        r=ProcessAlarm()
+        ProcessAlarm()
 #        if(r==1): #activated Alarm
 #            WriteIntoLogFile()
 #            StopMeasurement()
@@ -162,8 +162,8 @@ def TimerLoop(): #(interval: sampling*sample_smoothing*value_smoothing)
             
         WriteIntoLogFile()
         
-        Pixels=data.arrDataIndex/data.arrXscale[data.Xscale]
-        data.GraphStart=max(Pixels-779, 0)
+        GraphLen=data.arrDataIndex/data.arrXscale[data.Xscale]
+        data.GraphStart=max(GraphLen-779, 0)
 #        print data.GraphStart      
         
         data.ChangesInGraph=1 #Make sure it only gets refreshed once
@@ -200,8 +200,11 @@ def InitStartMeasurement():
     if(data.QuickMode==0):
         data.interval=data.sampling #normal
         if(data.OfflineMode=="True"): #change to offline mode
-            cmd="dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:\"offline\""
-            os.popen(cmd)
+            try:
+                cmd="dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:\"offline\""
+                os.popen(cmd)
+            except:
+                pass
         data.Xscale=1 #set to default zoom level
     else:  
         data.interval=10 #Fast mode for testing
@@ -317,10 +320,13 @@ def StopMeasurement():
     
     if(data.QuickMode==0): #normal mode
         if(data.OfflineMode=="True" and data.demo!=1): #change to offline mode
-            cmd="dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:\"normal\""
-            os.popen(cmd)
-    else: #test mode
-        data.test=0 # reset test mode if was active
+            try:
+                cmd="dbus-send --system --dest=com.nokia.mce --type=method_call /com/nokia/mce/request com.nokia.mce.request.req_device_mode_change string:\"normal\""
+                os.popen(cmd)
+            except:
+                pass
+#    else: #test mode
+#        data.test=0 # reset test mode if was active
 
 
 
@@ -335,14 +341,14 @@ def Zoom(direction):
         if(data.Xscale==0): return
         ViewWindow.ui.bZoomOut.setEnabled(True)
         data.Xscale=(data.Xscale-1) % data.arrXscaleLen
-        ProcessData()
-        data.ChangesInGraph=1 #Make sure it only gets refreshed once
+#        ProcessData()
+#        data.ChangesInGraph=1 #Make sure it only gets refreshed once
     else: # -1, zoom out
         if(data.Xscale==data.arrXscaleLen-1): return
         ViewWindow.ui.bZoomIn.setEnabled(True)
         data.Xscale=(data.Xscale+1) % data.arrXscaleLen
-        ProcessData()
-        data.ChangesInGraph=1 #Make sure it only gets refreshed once
+#        ProcessData()
+#        data.ChangesInGraph=1 #Make sure it only gets refreshed once
 
 
 
@@ -356,13 +362,13 @@ def MoveTrigger(direction):
     if(direction==+1): #up
         data.trigger=data.trigger+1
         if(data.trigger>data.maxtrigger): data.trigger=data.maxtrigger      
-        ProcessData()
-        data.ChangesInGraph=1 #Make sure it only gets refreshed once
+#        ProcessData()
+#        data.ChangesInGraph=1 #Make sure it only gets refreshed once
     else: #-1, down
         data.trigger=data.trigger-1
         if(data.trigger<0): data.trigger=0
-        ProcessData()
-        data.ChangesInGraph=1 #Make sure it only gets refreshed once
+#        ProcessData()
+#        data.ChangesInGraph=1 #Make sure it only gets refreshed once
 
 
 
@@ -418,7 +424,7 @@ class frmStartWindow(QMainWindow):
     def StartMeasurementNormal(self):
         print "Measure in normal Mode"
         data.QuickMode=0 #run in normal mode
-        data.test=0 #show axis lables        
+#        data.test=0 #show axis lables        
         self.StartMeasurement()
         
         
@@ -429,7 +435,7 @@ class frmStartWindow(QMainWindow):
         print "Measure in QuickMode"
         data.QuickMode=1 #run in quick mode (for testing only)
         data.Xscale=0 #default zoom level
-        data.test=1 #hide axis lables
+#        data.test=1 #hide axis lables
         self.StartMeasurement()
         
         
@@ -674,7 +680,7 @@ class frmRecordWindow(QMainWindow):
             StopMeasurement()
             self.AskKeepRecord()  
             self.UpdateScreenStop()
-            data.test=0 # reset test mode if was active
+#            data.test=0 # reset test mode if was active
         
                 
     def ZoomIn(self):
@@ -702,6 +708,7 @@ class frmRecordWindow(QMainWindow):
         self.ui.bLowerTrigger.setEnabled(True)
         if(data.trigger==data.maxtrigger): self.ui.bRaiseTrigger.setEnabled(False)
         else: self.ui.bRaiseTrigger.setEnabled(True)
+        data.ChangesInGraph=1 #Make sure it only gets refreshed once
         self.update() 
         self.UpdateScreen()
         
@@ -710,6 +717,7 @@ class frmRecordWindow(QMainWindow):
         self.ui.bRaiseTrigger.setEnabled(True)
         if(data.trigger==0): self.ui.bLowerTrigger.setEnabled(False)
         else: self.ui.bLowerTrigger.setEnabled(True)
+        data.ChangesInGraph=1 #Make sure it only gets refreshed once
         self.update()
         self.UpdateScreen()
 
@@ -871,10 +879,10 @@ class frmViewWindow(QMainWindow):
             
             
                         
-        Pixels=data.arrDataIndex/data.arrXscale[data.Xscale]
-#        data.GraphStart=min(data.GraphStart+360, max(Pixels-775, 0))
+        GraphLen=data.arrDataIndex/data.arrXscale[data.Xscale]
+#        data.GraphStart=min(data.GraphStart+360, max(GraphLen-775, 0))
 #        print data.GraphStart
-        if(data.GraphStart<max(Pixels-779, 0)): self.ui.bRight.setEnabled(True)
+        if(data.GraphStart<max(GraphLen-779, 0)): self.ui.bRight.setEnabled(True)
         else: self.ui.bRight.setEnabled(False)
         if(data.GraphStart>0): self.ui.bLeft.setEnabled(True)
         else: self.ui.bLeft.setEnabled(False)
@@ -884,7 +892,7 @@ class frmViewWindow(QMainWindow):
 
     def ShowLogFile(self):
         WriteConfig() #save all parameters as they will get changed
-        r=OpenLogFile()    
+        r=LoadLogFile()    
         if(r==1): #file too long            
             QtGui.QMessageBox.warning(self, 'Record too long!', "The record is too long. The end will be cut off!", QtGui.QMessageBox.Ok)
         elif(r==2): #file does not exist
@@ -894,13 +902,13 @@ class frmViewWindow(QMainWindow):
         elif(r==3): #file is corrupted => draw empty graph
             QtGui.QMessageBox.warning(self, 'File corrupded!', "The data in the record file\n"+data.logfilename+"\nis invalid!\nNo data loaded.", QtGui.QMessageBox.Ok)
         elif(r==4): #file is empty
-            QtGui.QMessageBox.warning(self, 'File empty!', "The data in the record file\n"+data.logfilename+"\ncontains no data!\nNo data loaded.", QtGui.QMessageBox.Ok)
+            QtGui.QMessageBox.warning(self, 'File empty!', "The data in the record file\n"+data.logfilename+"\ncontains no data!", QtGui.QMessageBox.Ok)
         LoadFileList()
-        ProcessData()
+        ProcessData(True)
         data.Xscale=1 #default zoom level
 #        data.GraphStart=0        
-        Pixels=data.arrDataIndex/data.arrXscale[data.Xscale]
-        data.GraphStart=max(Pixels-779, 0)
+        GraphLen=data.arrDataIndex/data.arrXscale[data.Xscale]
+        data.GraphStart=max(GraphLen-779, 0)
         data.ChangesInGraph=1 #Make sure it only gets refreshed once
         ViewWindowGraph = ViewWindowCanvas(self)
         ViewWindowGraph.show()
@@ -930,8 +938,9 @@ class frmViewWindow(QMainWindow):
         if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
         else: self.ui.bZoomIn.setEnabled(True)
 #        data.GraphStart=0
-        Pixels=data.arrDataIndex/data.arrXscale[data.Xscale]
-        data.GraphStart=max(Pixels-779, 0)
+        GraphLen=data.arrDataIndex/data.arrXscale[data.Xscale]
+        data.ChangesInGraph=1 #Make sure it only gets refreshed once
+        data.GraphStart=max(GraphLen-779, 0)
         self.update()
         self.UpdateScreen()
 
@@ -942,8 +951,9 @@ class frmViewWindow(QMainWindow):
         if(data.Xscale==data.arrXscaleLen-1): self.ui.bZoomOut.setEnabled(False)
         else: self.ui.bZoomOut.setEnabled(True)
 #        data.GraphStart=0
-        Pixels=data.arrDataIndex/data.arrXscale[data.Xscale]
-        data.GraphStart=max(Pixels-779, 0)
+        GraphLen=data.arrDataIndex/data.arrXscale[data.Xscale]
+        data.GraphStart=max(GraphLen-779, 0)
+        data.ChangesInGraph=1 #Make sure it only gets refreshed once
         self.update()
         self.UpdateScreen()
         
@@ -951,11 +961,13 @@ class frmViewWindow(QMainWindow):
 
     def RaiseTrigger(self):   
         MoveTrigger(+1)
+        data.ChangesInGraph=1 #Make sure it only gets refreshed once
         self.update() 
         self.UpdateScreen()
         
     def LowerTrigger(self):     
         MoveTrigger(-1)
+        data.ChangesInGraph=1 #Make sure it only gets refreshed once
         self.update()
         self.UpdateScreen()
     
@@ -964,7 +976,7 @@ class frmViewWindow(QMainWindow):
         
     def goLeft(self):
         Show_passed_time("Scroll left",   1)
-        Pixels=data.arrDataIndex/data.arrXscale[data.Xscale]
+#        GraphLen=data.arrDataIndex/data.arrXscale[data.Xscale]
         data.GraphStart=max(data.GraphStart-600, 0)
 #        print data.GraphStart                
         data.ChangesInGraph=1 #Make sure it only gets refreshed once
@@ -974,8 +986,8 @@ class frmViewWindow(QMainWindow):
         
     def goRight(self):
         Show_passed_time("Scroll right",   1)
-        Pixels=data.arrDataIndex/data.arrXscale[data.Xscale]
-        data.GraphStart=min(data.GraphStart+600, max(Pixels-779, 0))
+        GraphLen=data.arrDataIndex/data.arrXscale[data.Xscale]
+        data.GraphStart=min(data.GraphStart+600, max(GraphLen-779, 0))
 #        print data.GraphStart        
         data.ChangesInGraph=1 #Make sure it only gets refreshed once
         self.update()
@@ -984,7 +996,7 @@ class frmViewWindow(QMainWindow):
         
 
     def DeleteLogFile(self):
-        reply = QtGui.QMessageBox.question(self, 'Delete Record?', "Are you sure you want to delete this record?", QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
+        reply = QtGui.QMessageBox.question(self, 'Delete Record?', "Are you sure you want to delete this record:\n"+data.logfilename, QtGui.QMessageBox.Yes, QtGui.QMessageBox.No)
         if reply == QtGui.QMessageBox.Yes:
             print "Delete logfile: "+data.logfilename
             os.remove(data.logfolder+data.logfilename)    
@@ -1298,7 +1310,7 @@ class frmAlarmTimeWindow(QMainWindow):
 class RecordWindowCanvas(QtGui.QWidget):
     def __init__(self, parent):
         QMainWindow.__init__(self, parent)    
-        self.setGeometry(9, 180, 782, data.Ysize+55)
+        self.setGeometry(9, 180, 784, data.Ysize+55)
     
     def paintEvent(self, event):
         showGraph(self,  QtGui)
@@ -1312,7 +1324,7 @@ class RecordWindowCanvas(QtGui.QWidget):
 class ViewWindowCanvas(QtGui.QWidget):
     def __init__(self, parent):
         QMainWindow.__init__(self, parent)    
-        self.setGeometry(9, 100, 782, data.Ysize+55)
+        self.setGeometry(9, 100, 784, data.Ysize+55)
     
     def paintEvent(self, event):
         showGraph(self,  QtGui)
